@@ -2,7 +2,7 @@
   libakai - C++ cross-platform akai sample disk reader
   Copyright (C) 2002-2003 Sbastien Mtrot
 
-  Linux port by Christian Schoenebeck <cuse@users.sourceforge.net> 2003-2019
+  Linux port by Christian Schoenebeck <cuse@users.sourceforge.net> 2003-2025
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -637,17 +637,17 @@ bool AkaiProgram::Load()
   return true;
 }
 
-uint AkaiProgram::ListSamples(std::list<String>& rSamples)
+uint AkaiProgram::ListSamples(std::list<String>& /*rSamples*/)
 {
   return 0;
 }
 
-AkaiSample* AkaiProgram::GetSample(uint Index)
+AkaiSample* AkaiProgram::GetSample(uint /*Index*/)
 {
   return NULL;
 }
 
-AkaiSample* AkaiProgram::GetSample(const String& rName)
+AkaiSample* AkaiProgram::GetSample(const String& /*rName*/)
 {
   return NULL;
 }
