@@ -531,7 +531,7 @@ namespace sf2 {
         }
     }
 
-    void Region::SetModulator(sf2::File* pFile, ModList& Mod) {
+    void Region::SetModulator(sf2::File* /*pFile*/, ModList& Mod) {
         modulators.push_back(ModulatorItem(Mod));
         /*switch(srcType) {
             case NO_CONTROLLER:
